@@ -265,7 +265,12 @@ sub is_alive {
     my $self = shift;
     return 0 unless $self->{pid};
 
-    return 1 if $self->{_args}->{process_name} eq $self->{pid}->command() && $self->{pid}->cankill();
+    if ($self->{_args}->{process_name}) {
+        return 1 if $self->{pid}->command() && $self->{pid}->command() eq $self->{_args}->{process_name};
+    }
+    else {
+        return 1 if $self->{pid}->command();
+    }
 
     return 0;
 }
